==> search_web-0.1.4.tar.gz: search_web-0.1.4/README.md <==
# search_web



## This module will Help You to Search on Different Websites like Google,Youtube,etc.


### You can search on more than 45 websites very easily by just 2 lines of code.



### Short Description 



` So First Install the module `


```python 

pip install search-web

```

`Code` is so simple Just 2 lines of `Code`


```python

from pysearch import *
google_search("How to Search via pysearch module Python")

```


### New Updates

**0.1.4**  (21/01/2021)

+ Bug Fixes



### Long Description

### Websites Supported:-


	1.Google - `google_search("Python")`
	
	2.Youtube - ` youtube_search("Python")`
	
	3.Bing - `bing_search("Python")`
	
	4.Quora - `quora_search("5 Python Projects")`
	
	5.Python - `python_search("Input in Python")`
	
	6.Twitter - `twitter_search("Python")`
	
	7.Facebook - `facebook_search("Python")`
	
	8.Pinterest - `pinterest_search("Python images")`
	
	9.Wikipedia - `wikipedia_search("Python_(programming_language)")`
	
	10.Amazon - `amazon_search("Python Books")`
	
	11.Reddit - `reddit_search("Python")`
	
	12.Imdb - `imdb_search("python")`
	
	13.TripAdvisor - `tripadvisor_search("London")`
	
	14.Walmart - `walmart_search("python Books")`
	
	15.Craigslist - `craigslist_search("Python")`
	
	16.Ebay - `ebay_search("Python books")`
	
	17.LinkedIn- Job Search, People Search, Learning
	
	18.Playstore -`playstore_search("python")`
	
	19.Headline -`headline_search("python")`
	
	20.Esty - `esty_search("python")`
	
	21.Indeed - `indeed_search("Python Developer","USA")`
	
	22.Apple - `apple_search("Mac Book Pro")`
	
	23.ESPN - `espn_search("Cricket")`
	
	24.Webmd - `webmd_search("Python")`
	
	25.New York Times -`nytimes_search("Covid-19")`
	
	26.CNN - `cnn_search("Us elections 2020")`
	
	27.Best Buy- `bestbuy_search("Python")`
	
	28.Britanica-`britannica_search("Anything")`
	
	29.Bussiness Insider- `businessinsider__search("News")`
	
	30.Dictionary- `dictionary_search("graphics")`
	
	31.Gamepedia- `gamepedia_search("Minecraft")`

	32.Github- `github_search("ankitsinghprograms")`

	33.Home depot- `homedepot_search("News")`

	34.MapQuest- `mapquest_search("California,USA")`

	35.Mayo clinic- `mayoclinic_search("What to do during Fever")`

	36.Medical News Today- `medicalnewstoday_search("COVID-19")`

	37.Merriam Webster- `merriam_webster_search("News")`

	38.Microsoft- `microsoft_search("Mac Book Pro")`

	39.NIH- `nih_search("Usa News")`

	40.Quizlet- `quizlet_search("Std 8")`

	41.Rotten Tomatoes- `rottentomatoes_search("Water Bottle")`

	42.Target- `target_search("Anything")`

	43.Urban Dictionary- `urban_dictionary_search("LOL meaing in urban dictionary")`

	44.USA Today- `usatoday_search("USA election")`

	45.Yahoo- `yahoo_search("C++")`

	46.Zillow- `zillow_search("News")`





FUNCTIONS

+ `amazon_search(text) `

   [Amazon](https://www.amazon.com)



       Parameters
       ----------

       text:- The query which you want to search about (str)


+ `apple_search(text)`

   [Apple](https://www.apple.com/us)


        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+  `bing_search(text)`
    
   [Bing](https://www.bing.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `cnn_search(text)`

  [CNN](https://edition.cnn.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `craigslist_search(text)`

   [Craigslist](https://kolkata.craigslist.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `ebay_search(text)`

   [Ebay](https://www.ebay.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

 + `espn_search(text)`
    
   [ESPN](https://www.espn.in)

        Parameters
        -----------

        text:- The query which you want to search about (str)


  + `esty_search(text)`
    
    [Esty](https://www.etsy.c:om/in-en)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `facebook_search(text)`

   [Facebook](https://facebook.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

 + ` google_search(text)`
    
      [Google](https://www.google.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

 +  ` headline_search(text) `


    [Headline](https://www.healthline.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `imdb_search(text)`

    [IMDB](https://www.imdb.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

 +  `indeed_search(job_title, location)`

    [Indeed](https://in.indeed.com/m/jobs)

        Parameters
        -----------

        job_title:- Name of the Job (str)

        location:- Location (str)
        

+ `linkedin_job_search(text)`

    [Linkedin](https://www.linkedin.com/jobs)

        Parameters
        -----------

        text:- The query which you want to search about (str)


 +  `linkedin_learning_search(text)`

     [Linkedin](https://www.linkedin.com/learning)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `linkedin_people__search(first_name, last_name)`

    [Linkedin](https://www.linkedin.com/people-guest/pub)

        Parameters
        -----------

        first_name:- First Name of the person (str)

        last_name:- Last Name of the person (str)
        

+ `nytimes_search(text)`

    [New York Times](https://www.nytimes.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `pinterest_search(text)`

     [Pinterest](https://in.pinterest.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `play_store_search(text)`

    [Play Store](https://play.google.com/store)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `python_search(text)`

     [Python.org](https://www.python.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `quora_search(text)`

    [Quora](https://www.quora.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `reddit_search(text)`

   [Reddit](https://www.reddit.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `tripadvisor_search(text)`

   [Tripadvisor](https://www.tripadvisor.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `twitter_search(text`)

    [Twiiter](https://twitter.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `walmart_search(text)`

    [Walmart](https://www.walmart.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `webmd_search(text)`

    [Webmd](https://www.webmd.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `wikipedia_search(text)`

   [Wikipedia](https://en.m.wikipedia.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `youtube_search(text)`

    [Youtube](https://www.youtube.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `bestbuy_search(text)`
    
     [Best Buy](https://www.bestbuy.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
	
	
+ `britannica_search(text)`
    
     [Britanica](https://www.britannica.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `businessinsider__search(text)`
    
    [Bussiness Insider](https://www.businessinsider.in)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `dictionary_search(text)`
    
    [Dictionary](https://www.dictionary.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `gamepedia_search(text)`

    [Gamepedia](https://www.gamepedia.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `github_search(text)`

    [Github](https://github.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `homedepot_search(text)`

   [Homedepot](https://www.homedepot.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `mapquest_search(text)`

    [Mapquest](https://www.mapquest.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `mayoclinic_search(text)`
    
    [Mayoclinic](https://www.mayoclinic.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `medicalnewstoday_search(text)`
    
    [Medical News Today](https://www.medicalnewstoday.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `merriam_webster_search(text)`
    
    [Merriam Webster](https://www.merriam-webster.com/dictionary/)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
        
+ `microsoft_search(text)`
    
    [Microsoft](https://www.microsoft.com/en-in/)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `nih_search(text)`
    
    [NIH](https://search.nih.gov)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `quizlet_search(text)`
    
    [Quizlet](https://quizlet.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `rottentomatoes_search(text)`
    
    [Rotten Tomatoes](https://www.rottentomatoes.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)        
        
        
+ `target_search(text)`

     [Target](https://www.target.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)    
        
            
+ `urban_dictionary_search(text)`
    
    [Urban Dictionary](https://www.urbandictionary.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
            

+ `usatoday_search(text)`
    
     [USA Today](https://www.usnews.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
     
        
+ `yahoo_search(text)`
    
    [Yahoo](https://in.search.yahoo.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `zillow_search(text)`
    
    [Zillow](https://www.zillow.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
        
        
 ### Fotter
 
        
**Version-(0.1.4)-Bug Fixes**


**License-MIT**

==> search_web-0.1.5.tar.gz: search_web-0.1.5/README.md <==
# search_web



## This module will Help You to Search on Different Websites like Google,Youtube,etc.


### You can search on more than 45 websites very easily by just 2 lines of code.



### Short Description 



` So First Install the module `


```python 

pip install search-web

```

`Code` is so simple Just 2 lines of `Code`


```python

from search_web import *
google_search("How to search via search_web module python")


```


### New Updates

**0.1.5**  (21/01/2021)

+ Bug Fixes



### Long Description

### Websites Supported:-


	1.Google - `google_search("Python")`
	
	2.Youtube - ` youtube_search("Python")`
	
	3.Bing - `bing_search("Python")`
	
	4.Quora - `quora_search("5 Python Projects")`
	
	5.Python - `python_search("Input in Python")`
	
	6.Twitter - `twitter_search("Python")`
	
	7.Facebook - `facebook_search("Python")`
	
	8.Pinterest - `pinterest_search("Python images")`
	
	9.Wikipedia - `wikipedia_search("Python_(programming_language)")`
	
	10.Amazon - `amazon_search("Python Books")`
	
	11.Reddit - `reddit_search("Python")`
	
	12.Imdb - `imdb_search("python")`
	
	13.TripAdvisor - `tripadvisor_search("London")`
	
	14.Walmart - `walmart_search("python Books")`
	
	15.Craigslist - `craigslist_search("Python")`
	
	16.Ebay - `ebay_search("Python books")`
	
	17.LinkedIn- Job Search, People Search, Learning
	
	18.Playstore -`playstore_search("python")`
	
	19.Headline -`headline_search("python")`
	
	20.Esty - `esty_search("python")`
	
	21.Indeed - `indeed_search("Python Developer","USA")`
	
	22.Apple - `apple_search("Mac Book Pro")`
	
	23.ESPN - `espn_search("Cricket")`
	
	24.Webmd - `webmd_search("Python")`
	
	25.New York Times -`nytimes_search("Covid-19")`
	
	26.CNN - `cnn_search("Us elections 2020")`
	
	27.Best Buy- `bestbuy_search("Python")`
	
	28.Britanica-`britannica_search("Anything")`
	
	29.Bussiness Insider- `businessinsider__search("News")`
	
	30.Dictionary- `dictionary_search("graphics")`
	
	31.Gamepedia- `gamepedia_search("Minecraft")`

	32.Github- `github_search("ankitsinghprograms")`

	33.Home depot- `homedepot_search("News")`

	34.MapQuest- `mapquest_search("California,USA")`

	35.Mayo clinic- `mayoclinic_search("What to do during Fever")`

	36.Medical News Today- `medicalnewstoday_search("COVID-19")`

	37.Merriam Webster- `merriam_webster_search("News")`

	38.Microsoft- `microsoft_search("Mac Book Pro")`

	39.NIH- `nih_search("Usa News")`

	40.Quizlet- `quizlet_search("Std 8")`

	41.Rotten Tomatoes- `rottentomatoes_search("Water Bottle")`

	42.Target- `target_search("Anything")`

	43.Urban Dictionary- `urban_dictionary_search("LOL meaing in urban dictionary")`

	44.USA Today- `usatoday_search("USA election")`

	45.Yahoo- `yahoo_search("C++")`

	46.Zillow- `zillow_search("News")`





FUNCTIONS

+ `amazon_search(text) `

   [Amazon](https://www.amazon.com)



       Parameters
       ----------

       text:- The query which you want to search about (str)


+ `apple_search(text)`

   [Apple](https://www.apple.com/us)


        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+  `bing_search(text)`
    
   [Bing](https://www.bing.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `cnn_search(text)`

  [CNN](https://edition.cnn.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `craigslist_search(text)`

   [Craigslist](https://kolkata.craigslist.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `ebay_search(text)`

   [Ebay](https://www.ebay.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

 + `espn_search(text)`
    
   [ESPN](https://www.espn.in)

        Parameters
        -----------

        text:- The query which you want to search about (str)


  + `esty_search(text)`
    
    [Esty](https://www.etsy.c:om/in-en)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `facebook_search(text)`

   [Facebook](https://facebook.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

 + ` google_search(text)`
    
      [Google](https://www.google.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

 +  ` headline_search(text) `


    [Headline](https://www.healthline.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `imdb_search(text)`

    [IMDB](https://www.imdb.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

 +  `indeed_search(job_title, location)`

    [Indeed](https://in.indeed.com/m/jobs)

        Parameters
        -----------

        job_title:- Name of the Job (str)

        location:- Location (str)
        

+ `linkedin_job_search(text)`

    [Linkedin](https://www.linkedin.com/jobs)

        Parameters
        -----------

        text:- The query which you want to search about (str)


 +  `linkedin_learning_search(text)`

     [Linkedin](https://www.linkedin.com/learning)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `linkedin_people__search(first_name, last_name)`

    [Linkedin](https://www.linkedin.com/people-guest/pub)

        Parameters
        -----------

        first_name:- First Name of the person (str)

        last_name:- Last Name of the person (str)
        

+ `nytimes_search(text)`

    [New York Times](https://www.nytimes.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `pinterest_search(text)`

     [Pinterest](https://in.pinterest.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `play_store_search(text)`

    [Play Store](https://play.google.com/store)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `python_search(text)`

     [Python.org](https://www.python.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `quora_search(text)`

    [Quora](https://www.quora.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `reddit_search(text)`

   [Reddit](https://www.reddit.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `tripadvisor_search(text)`

   [Tripadvisor](https://www.tripadvisor.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `twitter_search(text`)

    [Twiiter](https://twitter.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `walmart_search(text)`

    [Walmart](https://www.walmart.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `webmd_search(text)`

    [Webmd](https://www.webmd.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `wikipedia_search(text)`

   [Wikipedia](https://en.m.wikipedia.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `youtube_search(text)`

    [Youtube](https://www.youtube.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `bestbuy_search(text)`
    
     [Best Buy](https://www.bestbuy.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
	
	
+ `britannica_search(text)`
    
     [Britanica](https://www.britannica.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `businessinsider__search(text)`
    
    [Bussiness Insider](https://www.businessinsider.in)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `dictionary_search(text)`
    
    [Dictionary](https://www.dictionary.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `gamepedia_search(text)`

    [Gamepedia](https://www.gamepedia.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `github_search(text)`

    [Github](https://github.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `homedepot_search(text)`

   [Homedepot](https://www.homedepot.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)


+ `mapquest_search(text)`

    [Mapquest](https://www.mapquest.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `mayoclinic_search(text)`
    
    [Mayoclinic](https://www.mayoclinic.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `medicalnewstoday_search(text)`
    
    [Medical News Today](https://www.medicalnewstoday.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `merriam_webster_search(text)`
    
    [Merriam Webster](https://www.merriam-webster.com/dictionary/)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
        
+ `microsoft_search(text)`
    
    [Microsoft](https://www.microsoft.com/en-in/)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `nih_search(text)`
    
    [NIH](https://search.nih.gov)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `quizlet_search(text)`
    
    [Quizlet](https://quizlet.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
+ `rottentomatoes_search(text)`
    
    [Rotten Tomatoes](https://www.rottentomatoes.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)        
        
        
+ `target_search(text)`

     [Target](https://www.target.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)    
        
            
+ `urban_dictionary_search(text)`
    
    [Urban Dictionary](https://www.urbandictionary.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
            

+ `usatoday_search(text)`
    
     [USA Today](https://www.usnews.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
     
        
+ `yahoo_search(text)`
    
    [Yahoo](https://in.search.yahoo.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        

+ `zillow_search(text)`
    
    [Zillow](https://www.zillow.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
        
        
 ### Fotter
 
        
**Version-(0.1.5)-Bug Fixes**


**License-MIT**
